@@ -639,7 +639,7 @@ gnome_xkb_info_new (void)
  *
  * Returns a list of all layout identifiers we know about.
  *
- * Return value: (transfer container) (element-type gchar): the list
+ * Return value: (transfer container) (element-type utf8): the list
  * of layout names. The caller takes ownership of the #GList but not
  * of the strings themselves, those are internally allocated and must
  * not be modified.
@@ -667,7 +667,7 @@ gnome_xkb_info_get_all_layouts (GnomeXkbInfo *self)
  *
  * Returns a list of all option group identifiers we know about.
  *
- * Return value: (transfer container) (element-type gchar): the list
+ * Return value: (transfer container) (element-type utf8): the list
  * of option group ids. The caller takes ownership of the #GList but
  * not of the strings themselves, those are internally allocated and
  * must not be modified.
@@ -689,6 +689,36 @@ gnome_xkb_info_get_all_option_groups (GnomeXkbInfo *self)
   return g_hash_table_get_keys (priv->option_groups_table);
 }
 
+/**
+ * gnome_xkb_info_description_for_group:
+ * @self: a #GnomeXkbInfo
+ * @group_id: identifier for group
+ *
+ * Return value: the translated description for the group @group_id.
+ *
+ * Since: 3.8
+ */
+const gchar *
+gnome_xkb_info_description_for_group (GnomeXkbInfo *self,
+                                      const gchar  *group_id)
+{
+  GnomeXkbInfoPrivate *priv;
+  const XkbOptionGroup *group;
+
+  g_return_val_if_fail (GNOME_IS_XKB_INFO (self), NULL);
+
+  priv = self->priv;
+
+  if (!ensure_rules_are_parsed (self))
+    return NULL;
+
+  group = g_hash_table_lookup (priv->option_groups_table, group_id);
+  if (!group)
+    return NULL;
+
+  return XKEYBOARD_CONFIG_(group->description);
+}
+
 /**
  * gnome_xkb_info_get_options_for_group:
  * @self: a #GnomeXkbInfo
@@ -697,7 +727,7 @@ gnome_xkb_info_get_all_option_groups (GnomeXkbInfo *self)
  * Returns a list of all option identifiers we know about for group
  * @group_id.
  *
- * Return value: (transfer container) (element-type gchar): the list
+ * Return value: (transfer container) (element-type utf8): the list
  * of option ids. The caller takes ownership of the #GList but not of
  * the strings themselves, those are internally allocated and must not
  * be modified.
